@@ -63,8 +63,10 @@ void bind_misc(py::module& m) {
         .value("custom8", morphio::enums::SectionType::SECTION_CUSTOM_8)
         .value("custom9", morphio::enums::SectionType::SECTION_CUSTOM_9)
         .value("custom10", morphio::enums::SectionType::SECTION_CUSTOM_10)
-        // .value("glia_process", morphio::enums::SectionType::SECTION_GLIA_PROCESS)
-        // .value("glia_endfoot", morphio::enums::SectionType::SECTION_GLIA_ENDFOOT)
+        .value("glia_perivascular_process",
+               morphio::enums::SectionType::SECTION_GLIA_PERIVASCULAR_PROCESS)
+        .value("glia_process", morphio::enums::SectionType::SECTION_GLIA_PROCESS)
+        .value("all", morphio::enums::SectionType::SECTION_ALL)
         .export_values();
 
     py::enum_<morphio::enums::VascularSectionType>(m, "VasculatureSectionType")
