@@ -1,15 +1,11 @@
-import os
 from itertools import product
 from pathlib import Path
 
-import morphio
 import numpy as np
 from morphio import Morphology, RawDataError, SomaError, ostream_redirect
-from nose import tools as nt
-from nose.tools import assert_equal, eq_, ok_
 from numpy.testing import assert_array_almost_equal, assert_array_equal
 
-from .utils import _test_asc_exception, assert_substring, captured_output, tmp_asc_file
+from utils import _test_asc_exception, tmp_asc_file
 
 DATA_DIR = Path(__file__).parent / 'data'
 
@@ -64,7 +60,7 @@ def test_soma():
                             [-1, 1, 0],
                             [-1, -1, 0]])
 
-        nt.assert_equal(len(n.root_sections), 0)
+        assert len(n.root_sections) == 0
 
 
 def test_parse_number_with_plus_symbol():
@@ -137,7 +133,7 @@ def test_single_neurite_no_soma():
         n = Morphology(tmp_file.name)
 
         assert_array_equal(n.soma.points, np.empty((0, 3)))
-        nt.assert_equal(len(n.root_sections), 1)
+        assert len(n.root_sections) == 1
         assert_array_equal(n.root_sections[0].points,
                            np.array([[1.2, 2.7, 1.0],
                                      [1.2, 3.7, 2.0]], dtype=np.float32))
@@ -163,7 +159,7 @@ def test_skip_header():
                          )''') as tmp_file:
 
         n = Morphology(tmp_file.name)
-        nt.assert_equal(len(n.root_sections), 1)
+        assert len(n.root_sections) == 1
         assert_array_equal(n.root_sections[0].points,
                            np.array([[1.2, 2.7, 1.0],
                                      [1.2, 3.7, 2.0]], dtype=np.float32))
@@ -212,7 +208,7 @@ would look like'''
     with tmp_asc_file(with_duplicate) as tmp_file:
         n = Morphology(tmp_file.name)
 
-    nt.assert_equal(len(n.root_sections), 1)
+    assert len(n.root_sections) == 1
 
     assert_array_equal(n.root_sections[0].points,
                        [[3, -4, 0],
@@ -317,8 +313,8 @@ def test_section_single_point():
                      )''') as tmp_file:
 
         n = Morphology(tmp_file.name)
-        nt.assert_equal(len(n.root_sections), 1)
-        nt.assert_equal(len(n.root_sections[0].children), 2)
+        assert len(n.root_sections) == 1
+        assert len(n.root_sections[0].children) == 2
         assert_array_equal(n.root_sections[0].children[0].points,
                            np.array([[3, -10, 0],
                                      [3, -10, 2]], dtype=np.float32))
@@ -358,21 +354,21 @@ def test_single_children():
 
         n = Morphology(tmp_file.name)
 
-        nt.assert_equal(len(n.soma.points), 0)
-        nt.assert_equal(len(n.soma.points), 0)
-        assert_equal(len(n.root_sections), 1)
+        assert len(n.soma.points) == 0
+        assert len(n.soma.points) == 0
+        assert len(n.root_sections) == 1
         assert_array_equal(n.root_sections[0].points,
                            np.array([[3, -4, 0],
                                      [3, -6, 0],
                                      [3, -8, 0],
                                      [3, -10, 0]],
                                     dtype=np.float32))
-        assert_equal(len(n.root_sections[0].children), 1)
+        assert len(n.root_sections[0].children) == 1
 
 
 def test_spine():
     neuron = Morphology(DATA_DIR / 'spine.asc')
-    assert_equal(len(neuron.root_sections), 1)
+    assert len(neuron.root_sections) == 1
     assert_array_equal(neuron.root_sections[0].points,
                        np.array([[3.22,    -1.15,   150.00],
                                  [5.84,    -2.17,   150.00],
@@ -428,7 +424,7 @@ def test_single_point_section_duplicate_parent_complex():
         neuron = Morphology(bad_tmp_file.name)
 
     children = neuron.root_sections[0].children
-    assert_equal(len(children), 3)
+    assert len(children) == 3
     assert_array_equal(children[0].points, [[2, 0, 0], [4, 0, 0]])
     assert_array_equal(children[1].points, [[2, 0, 0], [5, 0, 0]])
     assert_array_equal(children[2].points, [[2, 0, 0], [6, 0, 0]])
@@ -436,7 +432,7 @@ def test_single_point_section_duplicate_parent_complex():
 
 def test_spine():
     neuron = Morphology(DATA_DIR / 'spine.asc')
-    assert_equal(len(neuron.root_sections), 1)
+    assert len(neuron.root_sections) == 1
     assert_array_equal(neuron.root_sections[0].points,
                        np.array([[3.22,    -1.15,   150.00],
                                  [5.84,    -2.17,   150.00],
@@ -496,7 +492,7 @@ def test_markers():
 
         n = Morphology(tmp_file.name)
 
-        nt.assert_equal(len(n.root_sections), 1)
+        assert len(n.root_sections) == 1
 
         assert_array_equal(n.root_sections[0].points,
                            np.array([[-290.87,  -113.09,   -16.32],
@@ -535,16 +531,16 @@ def test_string_markers():
 
     # The for loop tests that the various constructors keep the markers alive
     for m in (cell, cell.as_mutable(), cell.as_mutable().as_immutable()):
-        assert_equal(len(m.root_sections), 1)
+        assert len(m.root_sections) == 1
         assert_array_equal(m.root_sections[0].points,
                            np.array([[-2.87, -9.24, -5.06],
                                      [-2.76, -10.41, -5.13],
                                      [-2.03, -12.48, -5.13],
                                      [-1.62, -13.30, -5.56]], dtype=np.float32))
 
-        assert_equal(len(m.markers), 2)
+        assert len(m.markers) == 2
         pia = m.markers[0]
-        assert_equal(pia.label, 'pia')
+        assert pia.label == 'pia'
         assert_array_equal(pia.points,
                            [[0, 1, 2],
                             [3, 4, 5],
@@ -552,7 +548,7 @@ def test_string_markers():
                             [9, 10, 11]])
         assert_array_equal(pia.diameters, [3, 4, 5, 6])
 
-        assert_equal(m.markers[1].label, 'layer1-2')
+        assert m.markers[1].label == 'layer1-2'
         assert_array_equal(m.markers[1].points,
                            np.array([[983.07, 455.36, -0.19],
                                      [1192.31, 420.35, -0.19]], dtype=np.float32))
@@ -606,7 +602,7 @@ def test_neurolucida_markers():
             neuron = Morphology(tmp_file.name)
 
         assert_array_equal(neuron.points, SIMPLE.points)
-        assert_equal(len(neuron.markers), 2)
+        assert len(neuron.markers) == 2
         assert_array_almost_equal(neuron.markers[0].points,
                                   np.array([[81.58, -77.98, -20.32]], dtype=np.float32))
         assert_array_almost_equal(neuron.markers[0].diameters,
